# Spacelift Client
Simple client library for working with the [spacelift.io](https://spacelift.io) API.

## Install
```bash
pip install spacelift
```

## Usage
```python
from spacelift import Spacelift
```
